# Changelog

## 0.1.0-alpha.1 (2024-10-28)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/CZL-AI/czl-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([1c4f87c](https://github.com/CZL-AI/czl-python/commit/1c4f87c000bed9ba0114ef4e3997c87f5f220f83))


### Chores

* configure new SDK language ([ad298c0](https://github.com/CZL-AI/czl-python/commit/ad298c0f2930abd896758bd57c4a9fa25bc214db))
* go live ([#1](https://github.com/CZL-AI/czl-python/issues/1)) ([fe8961c](https://github.com/CZL-AI/czl-python/commit/fe8961c8b2ddcdae4c9e1c82cc3667f411780fa2))
